==> 0.3.0.tar.gz: lib/src/ui/font_picker.dart <==
library flutter_font_picker;

import 'package:flutter/material.dart';

import '../constants/constants.dart';
import '../models/picker_font.dart';
import 'font_picker_ui.dart';

//TODO: Basic fonts option (to be included in assets)
//TODO: Filter languages according to selected fonts on init
//TODO: Implement favorites feature

/// Creates a widget that lets the user select a Google font from a provided list.
///
/// Inside your [build] method, use a button that when pressed, will navigate to the font picker screen:
///
/// ```dart
/// PickerFont? _selectedFont;
/// ElevatedButton(
///   child: Text('Pick a font'),
///   onPressed: () {
///     Navigator.push(
///       context,
///       MaterialPageRoute(
///           builder: (context) => FontPicker(
///               onFontChanged: (PickerFont font) {
///                 _selectedFont = font;
///                 print("${font.fontFamily} with font weight ${font.fontWeight} and font style ${font.fontStyle}.}");
///               },
///           ),
///       ),
///     );
///   }),
/// ```
///
///  The [onFontChanged] function retrieves the font that the user selects with an object containing details like the font's name, weight, style, etc.
///
/// You can then use its [toTextStyle] method to style any text with the selected font:
///
/// ```dart
/// Text('This will be styled with the font: $_selectedFont.fontFamily',
///      style: selectedFont.toTextStyle()),
/// ```
///
/// Use the [showInDialog] property to set if it will be shown in a dialog or in its own separate route.
class FontPicker extends StatefulWidget {
  /// The Google fonts that may be selected from the font picker. Check the [googleFontsList] constant for a list of the 975 fonts available.
  ///
  /// * Note that a large number of fonts can degrade the performance of the widget, as each font is downloaded and applied as a preview in the font picker.
  final List<String> googleFonts;

  /// The callback that returns a [PickerFont] object with all the details and methods for the font that the user selected.
  final ValueChanged<PickerFont> onFontChanged;

  /// The font family to use initially in the font picker. Defaults to 'Roboto'.
  final String initialFontFamily;

  /// Set whether to show font details (category, number of variants) next to each font tile in the list.
  final bool showFontInfo;

  /// Set to true if the font picker will be used in an [AlertDialog] (check examples for usage).
  final bool showInDialog;

  /// Fonts that the user selected before can be saved in [SharedPreferences] and shown at the start of the list. Sets how many you want saved as recents.
  final int recentsCount;

  /// Creates a widget that lets the user select a Google font from a provided list.
  ///
  /// The [onFontChanged] function retrieves the font that the user selects with an object containing details like the font's name, weight, style, etc.
  ///
  /// You can then use its [toTextStyle] method to style any text with the selected font.
  const FontPicker(
      {Key? key,
      this.googleFonts = googleFontsList,
      this.showFontInfo = true,
      this.showInDialog = false,
      this.recentsCount = 3,
      required this.onFontChanged,
      this.initialFontFamily = 'Roboto'})
      : super(key: key);

  @override
  _FontPickerState createState() => _FontPickerState();
}

class _FontPickerState extends State<FontPicker> {
  @override
  Widget build(BuildContext context) {
    if (widget.showInDialog) {
      return FontPickerUI(
        onFontChanged: widget.onFontChanged,
        googleFonts: widget.googleFonts,
        showFontInfo: widget.showFontInfo,
        showInDialog: widget.showInDialog,
        recentsCount: widget.recentsCount,
        initialFontFamily: widget.initialFontFamily,
      );
    } else {
      return Scaffold(
          appBar: AppBar(
            title: Text("Pick a font:"),
          ),
          body: FontPickerUI(
            onFontChanged: widget.onFontChanged,
            googleFonts: widget.googleFonts,
            showFontInfo: widget.showFontInfo,
            showInDialog: widget.showInDialog,
            recentsCount: widget.recentsCount,
            initialFontFamily: widget.initialFontFamily,
          ));
    }
  }
}

==> 0.3.3.tar.gz: lib/src/ui/font_picker.dart <==
library flutter_font_picker;

import 'package:flutter/material.dart';

import '../constants/constants.dart';
import '../models/picker_font.dart';
import 'font_picker_ui.dart';

//TODO: Basic fonts option (to be included in assets)
//TODO: Filter languages according to selected fonts on init
//TODO: Implement favorites feature

/// Creates a widget that lets the user select a Google font from a provided list.
///
/// Inside your [build] method, use a button that when pressed, will navigate to the font picker screen:
///
/// ```dart
/// PickerFont? _selectedFont;
/// ElevatedButton(
///   child: Text('Pick a font'),
///   onPressed: () {
///     Navigator.push(
///       context,
///       MaterialPageRoute(
///           builder: (context) => FontPicker(
///               onFontChanged: (PickerFont font) {
///                 _selectedFont = font;
///                 print("${font.fontFamily} with font weight ${font.fontWeight} and font style ${font.fontStyle}.}");
///               },
///           ),
///       ),
///     );
///   }),
/// ```
///
///  The [onFontChanged] function retrieves the font that the user selects with an object containing details like the font's name, weight, style, etc.
///
/// You can then use its [toTextStyle] method to style any text with the selected font:
///
/// ```dart
/// Text('This will be styled with the font: $_selectedFont.fontFamily',
///      style: selectedFont.toTextStyle()),
/// ```
///
/// Use the [showInDialog] property to set if it will be shown in a dialog or in its own separate route.
class FontPicker extends StatefulWidget {
  /// The Google fonts that may be selected from the font picker. Check the [googleFontsList] constant for a list of the 975 fonts available.
  ///
  /// * Note that a large number of fonts can degrade the performance of the widget, as each font is downloaded and applied as a preview in the font picker.
  final List<String> googleFonts;

  /// The callback that returns a [PickerFont] object with all the details and methods for the font that the user selected.
  final ValueChanged<PickerFont> onFontChanged;

  /// The font family to use initially in the font picker. Defaults to 'Roboto'.
  final String? initialFontFamily;

  /// Set whether to show font details (category, number of variants) next to each font tile in the list.
  final bool showFontInfo;

  /// Set to true if the font picker will be used in an [AlertDialog] (check examples for usage).
  final bool showInDialog;

  /// Fonts that the user selected before can be saved in [SharedPreferences] and shown at the start of the list. Sets how many you want saved as recents.
  final int recentsCount;

  /// Creates a widget that lets the user select a Google font from a provided list.
  ///
  /// The [onFontChanged] function retrieves the font that the user selects with an object containing details like the font's name, weight, style, etc.
  ///
  /// You can then use its [toTextStyle] method to style any text with the selected font.
  const FontPicker({
    Key? key,
    this.googleFonts = googleFontsList,
    this.showFontInfo = true,
    this.showInDialog = false,
    this.recentsCount = 3,
    required this.onFontChanged,
    this.initialFontFamily,
  }) : super(key: key);

  @override
  _FontPickerState createState() => _FontPickerState();
}

class _FontPickerState extends State<FontPicker> {
  @override
  Widget build(BuildContext context) {
    if (widget.showInDialog) {
      return FontPickerUI(
        onFontChanged: widget.onFontChanged,
        googleFonts: widget.googleFonts,
        showFontInfo: widget.showFontInfo,
        showInDialog: widget.showInDialog,
        recentsCount: widget.recentsCount,
        initialFontFamily: widget.initialFontFamily ?? 'Roboto',
      );
    } else {
      return Scaffold(
          appBar: AppBar(
            title: Text("Pick a font:"),
          ),
          body: FontPickerUI(
            onFontChanged: widget.onFontChanged,
            googleFonts: widget.googleFonts,
            showFontInfo: widget.showFontInfo,
            showInDialog: widget.showInDialog,
            recentsCount: widget.recentsCount,
            initialFontFamily: widget.initialFontFamily ?? 'Roboto',
          ));
    }
  }
}
